ReadDocumentTool

Struct ReadDocumentTool 

pub struct ReadDocumentTool {
    pub project_path: String,
    pub short_code: String,
}

Fields

project_path: String

Path to the .metis folder (e.g., “/Users/me/my-project/.metis”). Must end with .metis

short_code: String

Document short code (e.g., PROJ-V-0001) to identify the document

Implementations

Source

impl ReadDocumentTool

pub fn tool_name() -> String

Returns the name of the tool as a String.

pub fn request_params() -> CallToolRequestParams

Returns a CallToolRequestParams initialized with the current tool’s name.

You can further customize the request by adding arguments or other attributes using the builder pattern. For example:

let args = serde_json::Map::new();
let task_meta = TaskMetadata{ttl: Some(200)}

let params: CallToolRequestParams = MyTool::request_params()
    .with_arguments(args)
    .with_task(task_meta);
Returns

A CallToolRequestParams with the tool name set.

pub fn tool() -> Tool

Constructs and returns a rust_mcp_schema::Tool instance.

The tool includes the name, description, input schema, meta, and title derived from the struct’s attributes.

Source

impl ReadDocumentTool

Source

impl ReadDocumentTool